@@ -212,7 +212,7 @@ def downsize(input, output, ncpus, informat, outformat, size, bundle, mode, flat
 @click.option("--min-mean-luminance", "--ml", type=float, default=None,
               help="Don't keep originals with mean luminance < X. (black = 0 <= L <= 100 = white).")
 @click.option("--truncate-time", type=int, default=None, metavar="MINUTES",
-              help="Truncate time to N-mintue intervals.")
+              help="Truncate time to N-minute intervals.")
 @click.option("--NUKE", is_flag=True, default=False,
               help="DELETE file UNSAFELY as it finishes processsing")
 def ingest(input, informat, output, bundle, ncpus,
@@ -332,7 +332,7 @@ def ingest(input, informat, output, bundle, ncpus,
 @click.option("--NUKE", is_flag=True, default=False,
               help="DELETE file UNSAFELY as it finishes processsing")
 @click.option("--truncate-time", type=int, default=None, metavar="MINUTES",
-              help="Truncate time to N-mintue intervals.")
+              help="Truncate time to N-minute intervals.")
 def liveingest(input, informat, output, bundle, inotify_watch, nuke, min_mean_luminance, truncate_time,
                downsized_output, downsized_size, downsized_bundle,
                recoded_output, recoded_format, recoded_bundle,
@@ -509,9 +509,11 @@ def verify(ephemerals, resource, informat, force_delete, rm_script, move_dest, p
 @click.option("--order", "-O", default="colsright",
               type=Choice(["colsright", "colsleft", "rowsdown", "rowsup"]),
               help="Order in which images are taken (cols or rows, left orright)")
+@click.option("--ncpus", "-j", default=getncpu(),
+              help="Number of parallel workers")
 # time
 @click.option("--truncate-time", type=int, default=None, metavar="MINUTES",
-              help="Truncate time to N-mintue intervals.")
+              help="Truncate time to N-minute intervals.")
 # audit
 @click.option("--audit-output", "-a", type=Path(writable=True), default=None,
               help="Audit log output TSV. If given, input images will be audited, with the log saved here.")
@@ -528,14 +530,14 @@ def verify(ephemerals, resource, informat, force_delete, rm_script, move_dest, p
               help="Crop centre of each image. takes centre PROPORTION h x w from each image")
 # verbatim bundling
 @click.option("--bundle-output", "--bo", type=str, default=None,
-              help="Output timestream for verbtaim import images")
+              help="Output timestream for verbatim import images")
 @click.option("--bundle-level", "--bb", type=Choice(TimeStream.bundle_levels), default="none",
               help="Level at which to bundle verbatim images")
 # recoding
 @click.option("--recoded-output", "--ro", type=str, default=None,
               help="Output timestream for recoded import images")
 @click.option("--recoded-format", "--rf", type=str, default=None,
-              help="File format of  images")
+              help="File format of images")
 @click.option("--recoded-bundling", "--rb", type=Choice(TimeStream.bundle_levels), default="none",
               help="Level at which to bundle recoded images")
 # source removal
@@ -544,7 +546,7 @@ def verify(ephemerals, resource, informat, force_delete, rm_script, move_dest, p
 @click.option("--mv-destination", type=Path(), metavar="DIR",
               help="Instead of deleting input files, move files to DIR. (see --rm-script)")
 @click.argument("input")
-def gvmosaic(input, informat, dims, order, audit_output, composite_bundling,
+def gvmosaic(input, informat, dims, order, ncpus, audit_output, composite_bundling,
              composite_format, composite_size, composite_output, composite_centrecrop,
              bundle_output, bundle_level, recoded_output, recoded_format,
              recoded_bundling, rm_script, mv_destination, truncate_time):
@@ -554,17 +556,17 @@ def gvmosaic(input, informat, dims, order, audit_output, composite_bundling,
     ints = TimeStream(input, format=informat)
 
     composite_ts = TimeStream(composite_output, bundle_level=composite_bundling, add_subsecond_field=True)
-    steps = []
+    pipe = TSPipeline(multi_file_pipeline=True)
 
     if truncate_time is not None:
-        steps.append(TruncateTimeStep(truncate_time))
+        pipe.add_step(TruncateTimeStep(truncate_time))
 
     if bundle_output is not None:
         verbatim_ts = TimeStream(bundle_output, bundle_level=bundle_level)
-        steps.append(WriteFileStep(verbatim_ts))
+        pipe.add_step(WriteFileStep(verbatim_ts))
 
     # decode image
-    steps.append(DecodeImageFileStep())
+    pipe.add_step(DecodeImageFileStep())
 
     # run audit pipeline
     if audit_output is not None:
@@ -573,7 +575,7 @@ def gvmosaic(input, informat, dims, order, audit_output, composite_bundling,
             ImageMeanColourStep(),
             ScanQRCodesStep(),
         )
-        steps.append(audit_pipe)
+        pipe.add_step(audit_pipe)
 
     if recoded_output is not None:
         # run recode pipeline
@@ -582,23 +584,20 @@ def gvmosaic(input, informat, dims, order, audit_output, composite_bundling,
             EncodeImageFileStep(format=recoded_format),
             WriteFileStep(recoded_ts),
         )
-        steps.append(TeeStep(recoded_pipe))
+        pipe.add_step(TeeStep(recoded_pipe))
 
     # do mosaicing
-    steps.append(
+    pipe.add_step(
         TSPipeline(GigavisionMosaicStep(
             dims, composite_ts, subimgres=composite_size, order=order,
             output_format=composite_format, centrecrop=composite_centrecrop,
             rm_script=rm_script, mv_destination=mv_destination,
-        ))
+        ), multi_file_pipeline=True)
     )
 
-    # assemble total pipeline
-    pipe = TSPipeline(*steps)
-
     # run pipeline
     try:
-        for image in pipe.process(ints):
+        for image in pipe.process(ints, ncpus=ncpus):
             pass
     except Exception as exc:
         print(f"ERROR: {exc.__class__.__name__} {str(exc)}")
